qwen/qwen3-coder - OpenRouter

# qwen/qwen3-coder

A coding model with multiple provider offers.

## Available Providers

Provider | Model | Quantization | Context | Max Output | Throughput | Latency | Uptime | Input Price | Output Price
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
Chutes | qwen/qwen3-coder | fp16 | 32K | 16K | 18.5 TPS | 0.75s | 99.2% | $0.050000 | $0.120000
Chutes | qwen/qwen3-coder | int8 | 32K | 8K | 22.1 TPS | 0.65s | 99.2% | $0.050000 | $0.120000
DeepInfra | qwen/qwen3-coder | fp8 | 32K | 16K | 15.2 TPS | 0.85s | 99.5% | $0.060000 | $0.150000
Lambda | qwen/qwen3-coder | bf16 | 32K | 32K | 12.8 TPS | 1.20s | 98.9% | $0.070000 | $0.160000